<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Complaints_control extends CI_Controller
{

  public function __construct()
  {

    parent::__construct();

    if ($this->session->userdata('prosc_user') == '') redirect(base_url(), 'refresh');

    $this->load->model('complaints_model');
  }
  


  public function index()
  {
    $this->pager();
  }

  function pager($tmp = '')
  {
    if (!$this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '') redirect('google.com', 'refresh');
    $this->db->order_by('opened');
    $data = $this->complaints_model->_get(['status' => 0]) ?: [];
    $all_count = $this->complaints_model->_all_count() ?: '';
    $unread = $this->complaints_model->_count_unread() ?: '';
    $complains = $this->complaints_model->_count_all() ?: 1;
    if ($tmp == '') $this->load->view('default', ['page' => 'complaints', 'all_count' => $all_count, 'data' => $data, 'unread' => $unread, 'complains' => $complains, 'tmp' => $tmp]);
    else return $this->load->view('admin/complaints', ['data' => $data, 'unread' => $unread, 'complains' => $complains, 'tmp' => $tmp], true);
  }


  function check()
  {
    $name  = trim($this->input->post('name')) ?: trim($this->input->post('autogen'));
    $addr  = trim($this->input->post('address'));
    $state = trim($this->input->post('state'));
    if ($name == '' or $addr == '' or $state == '')
      return false;

    return [
      'name'    => $name,
      'type'    => 1,
      'address' => $addr,
      'state'   => $state
    ];
  }

  function create()
  {
    $data = $this->check();
    if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));

    if (!$this->message_model->_post($data))
      exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the insertion operation failed']));

    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    redirect(base_url('complaints.aspx'), 'refresh');
  }

  function update()
  {
    $target = trim($this->input->get('target'));
    if (!$this->message_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));
    $data = $this->check();
    if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));

    if (!$this->message_model->_put($data, $target))
      exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the update failed']));

    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
  }

  function delete()
  {
    $target = trim($this->input->get('token'));
    if (!$this->message_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));

    $this->message_model->_drop($target);
    $this->session->set_flashdata('prosc_message', 'Record Deleted');
    exit(json_encode(['status' => 'success', 'message' => '']));
  }

  function popup()
  {
    $file = $this->message_model->_get(['token' => $this->input->get('token')]);
    if (!$this->input->is_ajax_request() or !$file) {
      $pagedata['heading'] = 'Hold on!';
      $pagedata['message'] = 'The page you tried to reach, restricts direct access.';
      $this->load->view('errors/html/error_404', $pagedata);
    }

    $reply = $this->message_model->_get(['csr_order' => $this->input->get('token')]);

    $this->load->view('popups/admin/message', ['data' => $file, 'reply' => $reply]);
  }
}


//   function check()
//   {
//     $name  = trim($this->input->post('name'));
//     $unit  = trim($this->input->post('unit'));
//     $price = intval(trim($this->input->post('price')));
//     $cost_price = intval(trim($this->input->post('cost_price')));
//     $cate  = trim($this->input->post('category'));
//     $descr = trim($this->input->post('description'));
//     $image = $this->input->post('image');
//     if ($name == '' OR $price == '' OR $cost_price == '' OR $cate == '' OR $unit == '') return false;
//     // if ( ! ctype_alnum(str_replace(' ', '', $name))) return 'Product name cannot contain special characters';
//     if (is_numeric($name)) return 'Product name cannot be a number';
//     if ( ! is_numeric($price) OR $price < 1) return 'Product price must be a number greater than zero';
//     if ( ! is_numeric($cost_price) OR $cost_price < 1) return 'Product Cost price must be a number greater than zero';

//     $data = [
//       'name'        => $name,
//       'description' => $descr,
//       'unit'        => $unit,
//       'price'       => json_encode(['a577f519b58b533e400cf28a7464576babf92121'=>[$price, $cost_price]]),
//       'category'    => $cate,
//       'done_by'     => $this->session->userdata('prosc_admin')
//     ];
//     if ($image) $data['image'] = base64_decode($image);
//     return $data;
//   }

//   function create()
//   {
//     $data = $this->check();
//     if ( ! $data) exit(json_encode(['status'=>'error', 'message'=>'Fill in all required fields']));
//     if ( ! is_array($data)) exit(json_encode(['status'=>'error', 'message'=>$data]));

//     if ($this->items_model->_get(['name'=>$data['name'], 'unit'=>$data['unit'], 'category'=>$data['category']]))
//       exit(json_encode(['status'=>'error', 'message'=>'A similar item already exists in inventory']));
//     if ( ! $this->items_model->_post($data))
//       exit(json_encode(['status'=>'error', 'message'=>'An unknown error occured and the insertion operation failed']));

//     echo (json_encode(['status'=>'success', 'message'=>$this->pager('dump')]));
//   }

//   function update()
//   {
//     $target = trim($this->input->get('target'));
//     if ( ! $this->items_model->_get(['token'=>$target])) exit(json_encode(['status'=>'error', 'message'=>'A fatal error has occured. <br />Please refresh and try again']));
//     $data = $this->check();
//     if ( ! $data) exit(json_encode(['status'=>'error', 'message'=>'Fill in all required fields']));
//     if ( ! is_array($data)) exit(json_encode(['status'=>'error', 'message'=>$data]));

//     if ($this->items_model->_get(['token !='=>$target, 'name'=>$data['name'], 'unit'=>$data['unit'], 'category'=>$data['category']]))
//       exit(json_encode(['status'=>'error', 'message'=>'A similar item already exists in inventory']));

//     if ( ! $this->items_model->_put($data, $target))
//       exit(json_encode(['status'=>'error', 'message'=>'An unknown error occured and the update failed']));
    
//     echo (json_encode(['status'=>'success', 'message'=>$this->pager('dump')]));
//   }

//   function delete()
//   {
//     $target = trim($this->input->get('token'));
//     if ( ! $this->items_model->_get(['token'=>$target])) exit(json_encode(['status'=>'error', 'message'=>'A fatal error has occured. <br />Please refresh and try again']));

//     $this->items_model->_drop($target);
//     echo (json_encode(['status'=>'success', 'message'=>$this->pager('dump')]));
//   }

//   function popup()
//   {
//     if ( ! $this->input->is_ajax_request()) {
//       $pagedata['heading'] = 'Hold on!';
//       $pagedata['message'] = 'The page you tried to reach, restricts direct access.';
//       $this->load->view('errors/html/error_404', $pagedata);
//     }
//     $last = $this->items_model->_count() + 1;
//     $target = $this->input->get('token');
//     $data = ['data'=>'', 'last'=>$last];
//     $data['categories'] = $this->items_model->_get_categories() ?: [];
//     $file = $this->items_model->_get(['token'=>$target]);
//     $states = $this->items_model->_get_states(); $s = [];
//     if ($file) $data['data'] = $file;
//     $data['states'] = $states;
//     $this->load->view('popups/admin/item', $data);
//   }
