<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Debtors_control extends CI_Controller {
  
  public function __construct()
  {
    parent::__construct();

    if ($this->session->userdata('prosc_user') == '')
      redirect(base_url(), 'refresh');
    $this->load->model('debtor_model');
  }

  public function index()
  {
    $this->pager();
  }

  function pager($tmp='')
  {
    if ( ! $this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '') redirect(base_url('not_found.aspx'), 'refresh');
    if ($this->input->get('k') == 'history') return $this->history();
    $this->db->order_by('serial DESC');
    $data = $this->debtor_model->_get_all() ?: [];
    $users = $this->debtor_model->_get_users();
    $outlets = $this->debtor_model->_get_outlets();
    if ($tmp == '') $this->load->view('default', ['page'=>'debtors', 'data'=>$data, 'users'=>$users, 'outlets'=>$outlets, 'tmp'=>$tmp]);
    else return $this->load->view('admin/debtors', ['data'=>$data, 'users'=>$users, 'outlets'=>$outlets, 'tmp'=>$tmp], true);
  }

  function check()
  {
    $name   = trim($this->input->post('name'));
    // $days   = trim($this->input->post('days'));
    // $addr   = trim($this->input->post('address'));
    $phone  = trim($this->input->post('phone'));
    $email  = trim($this->input->post('email'));
    $address = trim($this->input->post('address'));
    // $outlet = trim($this->input->post('outlet'));

    if ($name == '' OR $phone == '' OR $address == '') return false;
    if ( ! ctype_alpha(str_replace(' ', '', $name))) return 'Enter a valid name';
    if ( ! is_numeric(substr($phone, 1)) OR strlen($phone) < 11 OR ! in_array(substr($phone, 0, 1), ['+', '0'])) return 'Phone number is invalid';
    if ($email && ! filter_var($email, FILTER_VALIDATE_EMAIL)) return 'Email is invalid';

    return [
      'name'      => $name,
      // 'days'      => $days,
      'phone'     => $phone,
      'email'     => $email,
      'type'      => 0,
      'address'   =>  $address,
      // 'warehouse' => $outlet
    ];
  }

  function create()
  {
    $data = $this->check();
    if ( ! $data) exit(json_encode(['status'=>'error', 'message'=>'Some fields were not properly filled']));
    if ( ! is_array($data)) exit(json_encode(['status'=>'error', 'message'=>$data]));
    if ( ! $this->debtor_model->_post($data))
      exit(json_encode(['status'=>'error', 'message'=>'An unknown error occured and the insertion operation failed']));

    echo (json_encode(['status'=>'success', 'message'=>$this->pager('dump')]));
  }

  function update()
  {
    $target = trim($this->input->get('target'));
    if ( ! $this->debtor_model->_get(['token'=>$target])) exit(json_encode(['status'=>'error', 'message'=>'A fatal error has occured. <br />Please refresh and try again']));
    $data = $this->check();
    if ( ! $data) exit(json_encode(['status'=>'error', 'message'=>'Fill in all fields']));
    if ( ! is_array($data)) exit(json_encode(['status'=>'error', 'message'=>$data]));
    if ( ! $this->debtor_model->_put($data, $target))
      exit(json_encode(['status'=>'error', 'message'=>'An unknown error occured and the update failed']));

    echo (json_encode(['status'=>'success', 'message'=>$this->pager('dump')]));
  }

  function delete()
  {
    $target = trim($this->input->get('token'));
    if ( ! $this->debtor_model->_get(['token'=>$target])) exit(json_encode(['status'=>'error', 'message'=>'A fatal error has occured. <br />Please refresh and try again']));

    $this->debtor_model->_drop($target);
    echo (json_encode(['status'=>'success', 'message'=>$this->pager('dump')]));
  }

  function history()
  {
    $target = $this->input->get('target');
    $data = $this->debtor_model->_get_history($target) ?: [];
    $payment = $this->debtor_model->_get_payments($target) ?: [];
    $client = $this->debtor_model->_get_client($target);
    $balances = $this->debtor_model->_get_balances($target);
    $this->load->view('default', ['page'=>'debtor_history', 'data'=>$data, 'payment'=>$payment, 'client'=>$client, 'balances'=>$balances]);
  }

  function popup()
  {
    if ( ! $this->input->is_ajax_request()) {
      $pagedata['heading'] = 'Hold on!';
      $pagedata['message'] = 'The page you tried to reach, restricts direct access.';
      $this->load->view('errors/html/error_404', $pagedata);
    }
    $target = $this->input->get('token');
    $last = $this->debtor_model->_count() + 1;
    $data = ['data'=>'', 'last'=>$last];
    $file = $this->debtor_model->_get(['token'=>$target]);
    $users = $this->debtor_model->_get_users();
    $outlets = $this->debtor_model->_get_outlets();
    if ($file) $data['data'] = $file;
    $data['users'] = $users;
    $data['outlets'] = $outlets;
    $this->load->view('popups/admin/debtor', $data);
  }
}
