<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Expenses_control extends CI_Controller
{

  public function __construct()
  {
    parent::__construct();

    if ($this->session->userdata('prosc_user') == '')
      redirect(base_url(), 'refresh');

    $this->load->model('expenses_model');
  }

  public function index()
  {
    $this->pager();
  }

  function pager($tmp = '')
  {
    if (!$this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '') redirect(base_url('not_found.aspx'), 'refresh');
    $data = $this->expenses_model->_get_all() ?: [];
    $stype = $this->expenses_model->_get_outlet($_SESSION['prosc_warehouse'])->type ?? '';
    $datac = $this->expenses_model->_get_account_types() ?: [];
    $station = $this->expenses_model->_get_station_list() ?: [];
    $users = $this->expenses_model->_get_users() ?: [];
    $data_list = $this->expenses_model->_get_account_list() ?: [];
    if ($tmp == '') $this->load->view('default', ['page' => 'expenses', 'data' => $data, 'users' => $users, 'stype' => $stype, 'tmp' => $tmp, 'station' => $station, 'account_types' => $datac, 'ledgers' => $data_list]);
    else return $this->load->view('admin/expenses', ['data' => $data, 'users' => $users, 'tmp' => $tmp, 'stype' => $stype, 'account_types' => $datac, 'ledgers' => $data_list, 'station' => $station], true);
  }

  function navigate($dir)
  {
    if (($dir != 'next' && $dir != 'prev')) return false;

    $chip = $dir == 'prev' ? '-1 days' : '+1 day';
    $dated = $this->session->userdata('prosc_expense_date') ?? date('Y-m-d');
    $dated = date('Y-m-d', strtotime($chip, strtotime($dated)));
    $this->session->set_userdata('prosc_expense_date', $dated);
    echo json_encode(['status' => 'success', 'message' => '']);
  }

  function check()
  {
    $comment = trim($this->input->post('comment'));
    $dated   = trim($this->input->post('dated'));
    $amount  = trim($this->input->post('amount'));
    $voucher = trim($this->input->post('voucher'));
    $ledgers_data = explode(':', trim($this->input->post('ledgers')));
    $ledgers = '';
    $account = '';

    $outlet = $this->expenses_model->_get_outlet($this->session->userdata('prosc_warehouse'));
    $user = $this->expenses_model->_get_user($this->session->userdata('prosc_user'));
    if (!$user or $comment == '' or count($ledgers_data) == 1 or $voucher == '' or $dated == '') return false;
    if ($dated > date('Y-m-d')) return 'Invalid date supplied';
    if (!is_numeric($amount) or $amount < 1) return 'Amount must be a number greater than zero';

    if (count($ledgers_data) > 1) {
      $ledgers = $ledgers_data[0];
      $account = $ledgers_data[1];
    }

    return [
      'reason'        => $comment,
      'date'          => $dated,
      'type'          => $outlet->type,
      'amount'        => $amount,
      'voucher'       => $voucher,
      'expenses_list' => $ledgers,
      'expenses_type' => $account,
      'done_by'       => $this->session->userdata('prosc_user'),
      'warehouse'     => $user->warehouse
    ];
  }

  function create()
  {
    $data = $this->check();
    if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Some fields were not properly filled']));
    if (!is_array($data)) exit(json_encode(['status' => 'error', 'message' => $data]));
    if (!$this->expenses_model->_post($data))
      exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the insertion operation failed']));

    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
  }

  function update()
  {
    $target = trim($this->input->get('target'));
    if (!$this->expenses_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));
    $data = $this->check();
    if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Some fields were not properly filled']));
    if (!is_array($data)) exit(json_encode(['status' => 'error', 'message' => $data]));

    if (!$this->expenses_model->_put($data, $target))
      exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the update failed']));

    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
  }

  function delete()
  {
    $target = trim($this->input->get('token'));
    if (!$this->expenses_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));

    $this->expenses_model->_drop($target);
    $this->session->set_flashdata('prosc_message', 'Record Deleted');
    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
  }

  function popup()
  {
    if (!$this->input->is_ajax_request()) {
      $pagedata['heading'] = 'Hold on!';
      $pagedata['message'] = 'The page you tried to reach, restricts direct access.';
      $this->load->view('errors/html/error_404', $pagedata);
    }
    $last = $this->expenses_model->_count() + 1001;
    $target = $this->input->get('token');
    $data = ['data' => '', 'last' => 'EX' . $last];
    $data['account_types'] = $this->expenses_model->_get_account_types() ?: [];
    $data['ledgers']  = $this->expenses_model->_get_account_list() ?: [];
    $file = $this->expenses_model->_get(['token' => $target]);
    if ($file) $data['data'] = $file;
    $this->load->view('popups/admin/expenses', $data);
  }
}
