<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Online_inventory_control extends CI_Controller
{

    public function __construct()
    {
        parent::__construct();

        if ($this->session->userdata('prosc_user') == '')
            redirect(base_url(), 'refresh');

        $this->load->model('dashboard_model');
        $this->load->model('online_inventory_model');
        $this->load->model('shipping_settings_model');
    }

    public function index()
    {
        $this->pager();
    }

    function pager($tmp = '')
    {
        if ((!$this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '')) redirect(base_url('not_found.aspx'), 'refresh');
        $data['tmp'] = $tmp;
        $data['page'] = 'online_inventory';
        $data['data'] = $this->online_inventory_model->_get_all() ?: [];
        $data['cats'] = $this->online_inventory_model->_get_cats() ?: [];
        $data['currency'] = $this->dashboard_model->_get_currency() ?: "";
        // $data['returns'] = $this->online_inventory_model->_get_returns();
        if ($tmp == '') $this->load->view('default', $data);
        else return $this->load->view('admin/online_inventory', $data, true);
    }

    function check()
    {
        $name  = trim($this->input->post('name')) ?: trim($this->input->post('autogen'));
        $addr  = trim($this->input->post('address'));
        $state = trim($this->input->post('state'));
        if ($name == '' or $addr == '' or $state == '')
            return false;

        return [
            'name'    => $name,
            'type'    => 1,
            'address' => $addr,
            'state'   => $state
        ];
    }

    function create()
    {
        $data = $this->check();
        if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));

        if (!$this->inventory_model->_post($data))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the insertion operation failed']));

        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }

    function update()
    {
        $target = trim($this->input->get('target'));
        if (!$this->inventory_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));
        $data = $this->check();
        if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));

        if (!$this->inventory_model->_put($data, $target))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the update failed']));

        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }

    function delete()
    {
        $target = trim($this->input->get('token'));
        if (!$this->inventory_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));

        $this->inventory_model->_drop($target);
        $this->session->set_flashdata('prosc_message', 'Record Deleted');
        exit(json_encode(['status' => 'success', 'message' => '']));
    }

    function popup()
    {
        if (!$this->input->is_ajax_request()) {
            $pagedata['heading'] = 'Hold on!';
            $pagedata['message'] = 'The page you tried to reach, restricts direct access.';
            $this->load->view('errors/html/error_404', $pagedata);
        }
        $data['data'] = [];
        $file = $this->inventory_model->_get_outlets();
        $country = $this->shipping_settings_model->_get_country();

        if ($country->value === 'Nigeria') {
            $states = $this->shipping_settings_model->_get_nigeria() ?: [];
        } else {
            $states = $this->shipping_settings_model->_get_uk() ?: [];
        }
        $s = [];
        if ($file) $data['data'] = $file;
        $data['states'] = $states;
        $this->load->view('popups/admin/inventory', $data);
    }
}
