<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Online_waybill_control extends CI_Controller
{

    public function __construct()
    {
        parent::__construct();

        if ($this->session->userdata('prosc_warehouse') == "")
            redirect(base_url(), 'refresh');
        $this->load->model('online_waybill_model');
        $this->load->model('shipping_settings_model');
    }

    public function index()
    {
        $this->pager();
    }

    function pager($tmp = '')
    {
        $target = $this->input->get('target');
        $token = $this->input->get('token');
        $data = $this->online_waybill_model->_get_all(['voucher' => $target], $token) ?: [];
        if (!$this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '') redirect(base_url('not_found.aspx'), 'refresh');
        if ($tmp == '') $this->load->view('default', ['page' => "online_waybill", 'data' => $data, 'target' => $target, 'token' => $token, 'tmp' => $tmp]);
        else return $this->load->view("admin/online_waybill", ['data' => $data, 'target' => $target, 'token' => $token, 'tmp' => $tmp], true);
    }

    function check($voucher)
    {

        $checkedItems = $this->input->post('item');
        $selectedTokens = [];
        $shipping = $this->online_waybill_model->_get_sales($voucher, true) ?: [];


        $selectedTokens = []; // Initialize an array to store selected tokens

        foreach ($checkedItems as $item) {
            // Assuming $shipping is a multi-dimensional array, 
            // $x should not be reset in each iteration
            $x = 0;

            // Check if $item exists in the 'token' field of $shipping[$x]
            if (in_array($item, $shipping[$x])) {
                // If it exists, add $item's token to $selectedTokens
                $selectedTokens[] = $shipping[$x]['token'];
            }

            // Increment $x if you intend to check against different indices of $shipping
            $x++;
        }



        $name  = trim($this->input->post('name'));
        $phone = trim($this->input->post('phone'));
        $state  = trim($this->input->post('state'));
        if ($name == '' or $phone == '' or $state == '') return false;
        if (!ctype_alpha(str_replace(' ', '', $name))) return 'Driver name is invalid';
        if (!is_numeric($phone) or strlen($phone) != 11) return 'Phone number must be 11 digits';


        $data = [
            'items'    => implode(' ', $checkedItems),
            'state'     => $state,
            'voucher' => $voucher,
            'phone'    => $phone,
            'driver'   => $name,
            'delivery_address' => $shipping[0]['delivery_address'],
            'shipping_token'   => implode(' ', $selectedTokens),
            'delivery' => 0,
        ];

        return $data;
    }


    function create()
    {
        $voucher = $this->input->get('voucher');
        $shipping_token = $this->input->get('token');

        $data = $this->check($voucher);
        if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
        if (!is_array($data)) exit(json_encode(['status' => 'error', 'message' => $data]));

        $target = $this->online_waybill_model->_post($data);
        if (!$target) exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the operation failed']));
        $items = explode(' ', $data['items']);
        $this->online_waybill_model->_mod($target, $items, $voucher);
        $this->online_waybill_model->_mod_shipping($target, $items);

        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }



    function popup()
    {
        if (!$this->input->is_ajax_request()) {
            $pagedata['heading'] = 'Hold on!';
            $pagedata['message'] = 'The page you tried to reach, restricts direct access.';
            $this->load->view('errors/html/error_404', $pagedata);
        }
        $target = $this->input->get('voucher');
        $token = $this->input->get('token');
        $waybill_data = ['data' => ''];
        $country = $this->shipping_settings_model->_get_country();

        if ($country->value === 'Nigeria') {
            $$waybill_data['states'] = $this->shipping_settings_model->_get_nigeria() ?: [];
        } else {
            $$waybill_data['states'] = $this->shipping_settings_model->_get_uk() ?: [];
        }


        $waybill_data['customers'] = $this->online_waybill_model->_get_customers() ?: [];
        $waybill_data['items'] = $this->online_waybill_model->_get_items() ?: [];
        $waybill_data['sales'] = $this->online_waybill_model->_get_sales($target);
        $waybill_data['voucher'] = $target;
        $waybill_data['token'] = $token;
        $this->load->view('popups/admin/online_waybill', $waybill_data);
    }
}
