<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Outlet_request_control extends CI_Controller
{

  public function __construct()
  {
    parent::__construct();


    if ($this->session->userdata('prosc_warehouse') == '' or $this->session->userdata('prosc_admin') == true)
      redirect(base_url(), 'refresh');
    $this->load->model('outlet_request_model');
    $this->load->model('notification_model');
  }

  public function index()
  {
    $this->pager();
  }

  function pager($tmp = '')
  {
    if (!$this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '') redirect(base_url('not_found.aspx'), 'refresh');
    $data = $this->outlet_request_model->_get_all() ?: [];
    $items = $this->outlet_request_model->_get_items() ?: [];
    $outlets = $this->outlet_request_model->_get_outlets() ?: [];
    $users = $this->outlet_request_model->_get_users() ?: [];
    if ($tmp == '') $this->load->view('default', ['page' => 'outlet_requests', 'data' => $data, 'items' => $items, 'tmp' => $tmp, 'outlets' => $outlets, 'users' => $users]);
    else return $this->load->view('admin/outlet_requests', ['data' => $data, 'items' => $items, 'tmp' => $tmp, 'outlets' => $outlets, 'users' => $users], true);
  }

  function check()
  {

    // $purpose = trim($this->input->post('purpose'));
    // $client  = trim($this->input->post('client'));
    $receive = trim($this->input->post('message'));
    $voucher  = trim($this->input->post('autogen'));

    $purpose  = 1;

    if ($purpose == '' or !in_array($purpose, [0, 1])) return false;

    if ($purpose == 1) {
      $data = [];
      foreach ($this->input->post() as $key => $value) {
        if (in_array($key, ['purpose', 'message', 'autogen']) or !is_numeric($value) or $value < 1) continue;
        $data[$key] = $value;
      }
      if (count($data) == 0 or max($data) < 1) return false;
      $receive = $data;
    }

    $info = array(
      'message' => $receive,
      'purpose' => $purpose
    );
    $message = json_encode($info);
    return [
      'message'   => $message,
      'messenger' => $this->session->userdata('prosc_user'),
      // 'customer'  => $client,
      'responder' => '',
      'warehouse' => $this->session->userdata('prosc_warehouse')
    ];
  }
  //check secion id 3 user and act accordingly


  function create()
  {

    $data = $this->check();
    if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Some fields were not properly filled']));
    $entry = $this->outlet_request_model->_post($data);
    if (!$entry)
      exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the insertion operation failed']));

    if ($this->session->userdata('prosc_type') == 3) {
      $named = 'Online Warehouse';
    } else {
      $named = $this->notification_model->_get_named('warehouse', $_SESSION['prosc_warehouse']);
    }
    $data = [
      'title'          => 'Supply Request from ' . $named,
      'type'           => 'supply',
      'notifier_token' => $entry,
      'notifier_url'   => base_url('ipanel/details.aspx?token=' . $entry),
      'views'          => $_SESSION['prosc_user'] . ' '
    ];
    $this->notification_model->_post($data);
    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
  }

  ///
  function update()
  {
    $target = trim($this->input->get('target'));
    if (!$this->outlet_request_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));
    $data = $this->check();
    if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
    if (!$this->outlet_request_model->_put($data, $target))
      exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the update failed']));

    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
  }

  function delete()
  {
    $target = trim($this->input->get('token'));
    if (!$this->outlet_request_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));

    $this->outlet_request_model->_drop($target);
    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
  }

  function popup()
  {
    if (!$this->input->is_ajax_request()) {
      $pagedata['heading'] = 'Hold on!';
      $pagedata['message'] = 'The page you tried to reach, restricts direct access.';
      $this->load->view('errors/html/error_404', $pagedata);
    }
    $target = $this->input->get('token');
    $file = $this->outlet_request_model->_get(['token' => $target]);
    $last = $this->outlet_request_model->_count() + 1001;
    $items = $this->outlet_request_model->_get_items();
    $clients = $this->outlet_request_model->_get_clients();
    $data = ['data' => '', 'items' => $items, 'clients' => $clients, 'last' => $last];
    if ($file) $data['data'] = $file;
    $this->load->view('popups/admin/outlet_request', $data);
  }
}
