<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Point_of_sales_control extends CI_Controller
{
    public function __construct()
    {
        parent::__construct();

        // Check user type and redirect if unauthorized
        if ($this->session->userdata('prosc_type') == 3) {
            redirect(base_url(), 'refresh');
        }

        // Load required models
        $this->load->model('point_of_sales_model');
        $this->load->model('dashboard_model');
        $this->load->model('sales_model');
        $this->load->model('inventory_model');
    }

    public function index()
    {
        // Load the pager view
        $this->pager();
    }

    public function pager($tmp = '')
    {
        // Check for valid AJAX request and URL format
        if (!$this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '') {
            redirect(base_url('not_found.aspx'), 'refresh');
        }

        // Retrieve necessary data
        $cat = $this->input->get('category');
        $currency = $this->dashboard_model->_get_currency() ?: "";
        $categories_with_item_count = $this->point_of_sales_model->get_random_categories_with_item_count() ?: [];
        $all_items_count = $this->point_of_sales_model->get_all_items_count() ?: "";
        $available_items = $this->point_of_sales_model->get_available_items($cat) ?: [];

        // Load appropriate view
        if ($tmp == '') {
            $this->load->view('default', [
                'page' => 'point_of_sales',
                'data' => [$categories_with_item_count, $available_items, $currency, $all_items_count],
                'tmp' => $tmp
            ]);
        } else {
            return $this->load->view('admin/point_of_sales', [
                'data' => [$categories_with_item_count, $available_items, $currency, $all_items_count],
                'tmp' => $tmp
            ], true);
        }
    }

    public function check()
    {
        // Parse JSON input from the frontend
        $input = file_get_contents('php://input');
        $data = json_decode($input, true);

        // Validate received data
        if (!isset($data['items'], $data['payment_method'], $data['total']) || empty($data['items']) || empty($data['payment_method']) || empty($data['total'])) {
            echo json_encode(['status' => 'error', 'message' => 'Invalid data submitted']);
            return;
        }

        // Retrieve necessary fields from session and input
        $items = $data['items'];
        $payment_method = $data['payment_method'];
        $subtotal = $data['subtotal'];
        $tax = $data['tax'];
        $total = $data['total'];

        $item_details = [];
        foreach ($items as $item) {
            // Validate item data
            if (!isset($item['token'], $item['quantity']) || empty($item['token']) || $item['quantity'] <= 0) {
                echo json_encode(['status' => 'error', 'message' => 'Invalid item data provided']);
                return;
            }

            // Get price information for the item
            $price = $this->sales_model->_get_price($item['token'], 'a577f519b58b533e400cf28a7464576babf92121');
            if (!$price) {
                echo json_encode(['status' => 'error', 'message' => 'Item price not found']);
                return;
            }

            $item_details[] = [
                'warehouse'        => $_SESSION['prosc_warehouse'],
                'date'             => date('Y-m-d'),
                'type'             => 0,
                'item'             => $item['token'],
                'price'            => $price[0],
                'payment_method'   => $payment_method,
                'total'            => $item['quantity'] * $price[0],
                'voucher'          => $this->sales_model->_count() + 1001,
                'cost_price'       => $price[1],
                'total_cost_price' => $item['quantity'] * $price[1],
                'quantity'         => $item['quantity'],
                'done_by'          => $_SESSION['prosc_user']
            ];
        }

        return $item_details;
    }

    public function create()
    {
        // Validate and process input data
        $data = $this->check();
        if (!is_array($data)) {
            exit(json_encode(['status' => 'error', 'message' => 'Invalid data provided']));
        }

        foreach ($data as $item_data) {
            // Prevent duplicate entries
            $check = ['item' => $item_data['item'], 'voucher' => $item_data['voucher']];
            if ($this->sales_model->_get($check)) {
                exit(json_encode(['status' => 'error', 'message' => 'This item already exists in the sale']));
            }

            // Update inventory
            $this->inventory_model->_aggregate($item_data['warehouse']);

            // Check stock availability
            if (!$this->sales_model->_evaluate($item_data['item'], $item_data['quantity'])) {
                exit(json_encode(['status' => 'error', 'message' => 'Insufficient stock for item: ' . $item_data['item']]));
            }

            // Post sale data to the database
            $token = $this->sales_model->_post($item_data);
            if (!$token) {
                exit(json_encode(['status' => 'error', 'message' => 'Failed to process sale for item: ' . $item_data['item']]));
            }
            $this->session->set_userdata('print_token', $token);
        }

        // Return success response
        echo json_encode(['status' => 'success',   'message' => 'Payment processed successfully']);
    }

    public function popup()
    {
        if (!$this->input->is_ajax_request()) {
            $pagedata['heading'] = 'Hold on!';
            $pagedata['message'] = 'The page you tried to reach restricts direct access.';
            $this->load->view('errors/html/error_404', $pagedata);
        }

        $data = ['states'];

        $this->load->view('popups/admin/print_receipt', $data);
    }
}
