<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Settings_pos_control extends CI_Controller
{
    public function __construct()
    {
        parent::__construct();

        // Check user type and redirect if unauthorized
        if (!$this->session->userdata('prosc_admin')) {
            redirect(base_url(), 'refresh');
        }

        // Load required models
        $this->load->model('settings_pos_model');
    }

    public function index()
    {
        // Load the pager view
        $this->pager();
    }

    public function pager($tmp = '')
    {
        // Check for valid AJAX request and URL format
        if (!$this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '') {
            redirect(base_url('not_found.aspx'), 'refresh');
        }

        // Retrieve necessary data
        $all_staff_pos = $this->settings_pos_model->_get_all_pos_staff() ?: [];


        // Load appropriate view
        if ($tmp == '') $this->load->view('default', ['page' => 'settings_pos', 'data' => $all_staff_pos, 'tmp' => $tmp]);
        else return $this->load->view('admin/settings_pos', ['data' => $all_staff_pos, 'tmp' => $tmp], true);
    }

    function check()
    {
        $staff   = trim($this->input->post('staff'));
        $pos   = trim($this->input->post('pos'));
        $password_1  = trim($this->input->post('drawer_code_1'));
        $password_2  = trim($this->input->post('drawer_code_2'));


        if ($staff == '' or $pos == '') exit(json_encode(['status' => 'error', 'message' => 'Select staff and POS']));
        if ($password_1 == '' or $password_2 == '') return false;
        if ($password_1 !=  $password_2) exit(json_encode(['status' => 'error', 'message' => 'Drawer codes do not match']));


        return [
            'staff'      => $staff,
            'pos_id'      => $pos,
            'cash_drawer_pwd'     => password_hash($password_2, PASSWORD_DEFAULT),
        ];
    }

    function create()
    {
        $data = $this->check();
        if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));

        if (!$this->settings_pos_model->_post($data))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the insertion operation failed']));

        if (!$this->settings_pos_model->_edit_staff($data['staff'], 'add'))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the staff operation failed']));

        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }

    function update()
    {
        $target = trim($this->input->get('target'));
        $old_staff = trim($this->input->get('old'));
        if (!$this->settings_pos_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));
        $data = $this->check();
        if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));

        if (!$this->settings_pos_model->_put($data, $target))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the update failed']));

        if (!$this->settings_pos_model->_edit_staff($old_staff, 'remove'))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the staff operation failed']));

        if (!$this->settings_pos_model->_edit_staff($data['staff'], 'add'))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the staff operation failed']));

        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }

    public function delete()
    {
        $target = trim($this->input->get('token'));
        $staff = trim($this->input->get('staff'));
        if (!$this->settings_pos_model->_get(['token' => $target])) {
            $this->jsonResponse('error', 'A fatal error has occurred. <br />Please refresh and try again.');
        }

        if (!$this->settings_pos_model->_edit_staff($staff, 'remove'))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the staff operation failed']));
        $this->settings_pos_model->_drop($target);
        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }

    function popup()
    {
        if (!$this->input->is_ajax_request()) {
            $pagedata['heading'] = 'Hold on!';
            $pagedata['message'] = 'The page you tried to reach, restricts direct access.';
            $this->load->view('errors/html/error_404', $pagedata);
        }
        $target = $this->input->get('token');
        $file = $this->settings_pos_model->_get(['token' => $target]);
        if ($target) {
            $all_staff = $this->settings_pos_model->_get_staff(true) ?: [];
        } else {
            $all_staff = $this->settings_pos_model->_get_staff() ?: [];
        }
        $all_pos = $this->settings_pos_model->_get_all_pos() ?: [];

        if ($file) $data['data'] = $file;
        $data['staff'] = $all_staff;
        $data['pos'] = $all_pos;
        $this->load->view('popups/admin/settings_pos', $data);
    }
}
