<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Shipping_settings_control extends CI_Controller
{

    public function __construct()
    {
        parent::__construct();

        if (!isset($_SESSION['prosc_user'])) redirect(base_url(), 'refresh');

        $this->load->model('shipping_settings_model');
    }

    public function index()
    {
        $this->pager();
    }

    function pager($tmp = '')
    {
        if (!$this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '') redirect(base_url('not_found.aspx'), 'refresh');
        $data['tmp'] = $tmp;
        $data['page'] = 'shipping_settings';
        $data['setting'] =  $this->shipping_settings_model->_get_shipping_settings() ?: [];
        $data['currency'] = $this->shipping_settings_model->_get_currency() ?: "";

        if ($tmp == '') $this->load->view('default', $data);
        else return $this->load->view('admin/shipping_settings', $data, true);
    }

    function check()
    {
        $region = trim($this->input->post('region'));
        $fee  = trim($this->input->post('fee'));


        if ($region == '') return false;
        if ($fee == '' or !is_numeric($fee)) return false;

        return [
            'region'       => $region,
            'fee'          => $fee
        ];
    }

    function create()
    {
        $data = $this->check();
        if (! is_array($data)) exit(json_encode(['status' => 'error', 'message' => 'Some fields were not properly filled']));
        if ($this->shipping_settings_model->_regions($data['region'])) exit(json_encode(['status' => 'error', 'message' => 'This entry already exists ']));
        if (! $this->shipping_settings_model->_post($data))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the insertion operation failed']));
        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }

    function update()
    {
        $target_token = $this->input->get('target');
        if ($target_token == '') exit(json_encode(['status' => 'error', 'message' => 'Token not provided. <br />Please refresh and try again']));

        $target = $this->shipping_settings_model->_get(['token' => trim($target_token)]);
        if (! $target) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));
        $data = $this->check();
        if (! $data) exit(json_encode(['status' => 'error', 'message' => 'Some fields were not properly filled']));
        if (! $this->shipping_settings_model->_put($data, $target->token))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the update failed']));
        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }

    function delete()
    {
        $target = trim($this->input->get('target'));
        if (! $this->shipping_settings_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));

        $this->shipping_settings_model->_drop($target);
        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }


    function popup()
    {
        if (! $this->input->is_ajax_request()) {
            $pagedata['heading'] = 'Hold on!';
            $pagedata['message'] = 'The page you tried to reach, restricts direct access.';
            $this->load->view('errors/html/error_404', $pagedata);
        }
        $target = $this->input->get('target');
        $file = $this->shipping_settings_model->_get(['token' => $target]);
        $data = ['data' => ''];
        $country = $this->shipping_settings_model->_get_country();
        $nigeria = $this->shipping_settings_model->_get_nigeria();
        $uk = $this->shipping_settings_model->_get_uk();
        $data['currency'] = $this->shipping_settings_model->_get_currency() ?: "";


        if ($file) $data['data'] = $file;

        $data['country'] = $country;
        if ($country->value == 'Nigeria') {
            $data['regions'] = $nigeria;
        } else {
            $data['regions'] = $uk;
        }
        $this->load->view('popups/admin/shipping_settings', $data);
    }
}
