<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Supply_client_control extends CI_Controller
{

    public function __construct()
    {
        parent::__construct();

        if (!isset($_SESSION['prosc_user']))
            redirect(base_url(), 'refresh');

        $this->load->model('supply_client_model');
        $this->load->model('dashboard_model');
        $this->load->model('shipping_settings_model');
    }

    public function index()
    {
        $this->pager();
    }

    function pager($tmp = '')
    {
        if (!$this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '') redirect(base_url('not_found.aspx'), 'refresh');
        $items = $this->supply_client_model->_get_items()     ?: [];
        $cats = $this->supply_client_model->_get_cats()       ?: [];
        $data  = $this->supply_client_model->_get_all()       ?: [];
        $totals = $this->supply_client_model->_get_sums()     ?: [];
        $country = $this->shipping_settings_model->_get_country();

        if ($country->value === 'Nigeria') {
            $states = $this->shipping_settings_model->_get_nigeria() ?: [];
        } else {
            $states = $this->shipping_settings_model->_get_uk() ?: [];
        }
        $clients = $this->supply_client_model->_get_clients() ?: [];
        $currency = $this->dashboard_model->_get_currency() ?: "";

        if ($tmp == '') $this->load->view('default', ['page' => 'supply_client', 'data' => $data, 'cats' => $cats, 'clients' => $clients, 'currency' => $currency, 'totals' => $totals, 'states' => $states, 'items' => $items, 'tmp' => $tmp]);
        else return $this->load->view('admin/supply_client', ['data' => $data, 'cats' => $cats, 'clients' => $clients, 'totals' => $totals, 'currency' => $currency, 'states' => $states, 'items' => $items, 'tmp' => $tmp], true);
    }

    function check_detail($token = '', $dated = '', $client = '', $byname = '', $bphone = '')
    {
        $name   = $token ?: trim($this->input->post('autogen'));
        $dated  = $dated ?: trim($this->input->post('dated'));
        $client = $client ?: trim($this->input->post('customer'));
        $byname = $byname ?: trim($this->input->post('name'));
        $bphone = $bphone ?: trim($this->input->post('phone'));

        $debtor = $this->supply_client_model->_get_client($client);
        if ($name == '' or $dated == '' or $client == '') exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
        if ($client == md5('er_empty') && ($byname == '' or $bphone == '')) exit(json_encode(['status' => 'error', 'message' => 'Customer name and phone number is required']));
        if ($dated > date('Y-m-d')) exit(json_encode(['status' => 'error', 'message' => 'Invalid date supplied']));
        if ($token == '' && $this->supply_client_model->_get_keyed($name)) exit(json_encode(['status' => 'error', 'message' => 'Request Error']));
        $check = ['date' => $dated, 'customer' => $client];
        if ($token == '' && $this->supply_client_model->_get($check)) exit(json_encode(['status' => 'error', 'message' => 'This Supply already exist']));

        if ($token != '') $name = $token;
        $_SESSION['prosc_supply_client_key'] = $name;
        $_SESSION['prosc_supply_client_date'] = $dated;
        $_SESSION['prosc_supply_client_name'] = $byname ?: $debtor->name;
        $_SESSION['prosc_supply_client_phone'] = $bphone ?: $debtor->phone;
        $_SESSION['prosc_supply_client_state'] = $_SESSION['prosc_warehouse'];
        $_SESSION['prosc_supply_client_client'] = $client;
        $data = ['message' => ''];
        if ($token == '') $data = ['message' => $this->pager('dump'), 'extra' => 'Starting Supply'];
        echo (json_encode(array_merge($data, ['status' => 'success'])));
    }

    // function navigate($dir)
    // {
    //   $client = $this->session->userdata('prosc_supply_client_client');
    //   if (($dir != 'next' && $dir != 'prev') OR !$this->supply_client_model->_get_client($client)) return false;

    //   $chip = $dir == 'prev' ? '-1 days' : '+1 day';
    //   $dated = $this->session->userdata('prosc_supply_client_date');
    //   $dated = date('Y-m-d', strtotime($chip, strtotime($dated)));
    //   $details = $this->supply_client_model->_get(['date'=>$dated, 'customer'=>$client]);
    //   $last = $this->supply_client_model->_count() + 1001;
    //   $last = str_repeat('0', 7 - strlen($last)) . $last;
    //   return $this->check_detail($details->voucher ?? $last, $dated, $client);
    // }

    function check()
    {
        $item   = trim($this->input->post('item'));
        $qty    = trim($this->input->post('quantity'));
        $price1 = $this->input->post('manual_price');
        $checkX = $this->input->post('setman');

        if ($item == '' or !is_numeric($qty)) return false;
        if ($qty < 1) return -1;
        if ($checkX && (!is_numeric($price1) or $price1 < 1)) return -2;

        $price = $this->supply_client_model->_get_price($item, 'a577f519b58b533e400cf28a7464576babf92121') ?: [];
        return [
            'date'      => $_SESSION['prosc_supply_client_date'],
            'voucher'   => $_SESSION['prosc_supply_client_key'],
            'price'     => (!$checkX ? $price[0] : $price1),
            'cost_price' => $price[1],
            'item'      => $item,
            'total'     => $qty * (!$checkX ? $price[0] : $price1),
            'total_cost_price' => $qty * $price[1],
            'customer_name' => $_SESSION['prosc_supply_client_name'],
            'customer_phone' => $_SESSION['prosc_supply_client_phone'],
            'warehouse' => $_SESSION['prosc_supply_client_state'],
            'customer'  => $_SESSION['prosc_supply_client_client'],
            'quantity'  => $qty,
            'done_by'   => $_SESSION['prosc_user']
        ];
    }

    function create()
    {
        if ($this->session->userdata('prosc_supply_client_key') == '') return $this->check_detail();

        $data = $this->check();
        if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Some fields were not properly filled']));
        if ($data == -1) exit(json_encode(['status' => 'error', 'message' => 'Quantity is invalid']));
        if ($data == -2) exit(json_encode(['status' => 'error', 'message' => 'Enter a valid price']));

        if (!$this->supply_client_model->_post($data))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the insertion operation failed']));

        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }

    function update()
    {
        $action = $this->input->get('action');
        if ($action != '') exit($this->$action());
        $target = trim($this->input->get('target'));
        if (!$this->supply_client_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));
        $data = $this->check();
        if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Some fields were not properly filled']));
        if ($data == -1) exit(json_encode(['status' => 'error', 'message' => 'Quantity is invalid']));
        if ($data == -2) exit(json_encode(['status' => 'error', 'message' => 'Enter a valid price']));
        $check = ['token !=' => $target, 'date' => $data['date'], 'item' => $data['item'], 'customer' => $data['customer'], 'voucher' => $data['voucher']];
        if ($this->supply_client_model->_get($check)) exit(json_encode(['status' => 'error', 'message' => 'This entry already exists in the Supply']));

        if (!$this->supply_client_model->_put($data, $target))
            exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the update failed']));

        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }

    function open()
    {
        $target = trim($this->input->get('target'));
        $supply = $this->supply_client_model->_get(['token' => $target]);
        if (!$supply) exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured while trying to open']));

        return $this->check_detail($supply->voucher, $supply->date, $supply->customer, $supply->customer_name, $supply->customer_phone);
    }

    function mod()
    {
        $dated  = trim($this->input->post('dated'));
        $client = trim($this->input->post('customer'));
        $target = $this->input->get('target');

        if ($dated == '' or $client == '') exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
        if ($dated > date('Y-m-d')) exit(json_encode(['status' => 'error', 'message' => 'Invalid date supplied']));
        if (!$this->supply_client_model->_get(['voucher' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));
        $check = ['date' => $dated, 'customer' => $client];
        if ($this->supply_client_model->_get($check)) exit(json_encode(['status' => 'error', 'message' => 'This Supply already exist']));
        $debtor = $this->supply_client_model->_get_client($client);
        if (!$debtor) exit(json_encode(['status' => 'error', 'message' => 'Request failed']));

        $data['date'] = $dated;
        $data['customer'] = $client;
        $data['customer_name'] = $debtor->name;
        $data['customer_phone'] = $debtor->phone;
        $this->supply_client_model->_put($data, ['voucher' => $target]);
        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }

    function close()
    {
        $this->supply_client_model->_close();
        $this->session->unset_userdata('prosc_supply_client_key');
        echo (json_encode(['status' => 'success', 'message' => '']));
    }

    function delete()
    {
        $target = trim($this->input->get('token'));
        if (!$this->supply_client_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));

        $this->supply_client_model->_drop($target);
        $this->session->set_flashdata('prosc_message', 'Record Deleted');
        echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }

    function popup()
    {
        $this->session->unset_userdata('prosc_supply_client_key');
        if (!$this->input->is_ajax_request()) {
            $pagedata['heading'] = 'Hold on!';
            $pagedata['message'] = 'The page you tried to reach, restricts direct access.';
            $this->load->view('errors/html/error_404', $pagedata);
        }
        $target = $this->input->get('token');
        $last = $this->supply_client_model->_count() + 1001;
        $last = str_repeat('0', 7 - strlen($last)) . $last;
        if (!isset($_SESSION['prosc_admin'])) $this->db->where('warehouse', $_SESSION['prosc_warehouse']);
        $clients = $this->supply_client_model->_get_clients();
        $data['data']    = [];
        $data['voucher'] = $last;
        $data['clients'] = $clients;
        $file = $this->supply_client_model->_get(['token' => $target]);
        if ($file) $data['data'] = $file;
        $this->load->view('popups/admin/supply_client', $data);
    }
}
