<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Users_control extends CI_Controller
{

  public function __construct()
  {
    parent::__construct();

    if ($this->session->userdata('prosc_admin') !== true)
      redirect(base_url(), 'refresh');
    $this->load->model('user_model');
  }

  public function index()
  {
    $this->pager();
  }

  function pager($tmp = '')
  {
    if (!$this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '') redirect(base_url('not_found.aspx'), 'refresh');

    $data = $this->user_model->_get_all() ?: [];
    $states = $this->user_model->_get_states() ?: [];
    $outlets = $this->user_model->_get_outlets() ?: [];
    $spo = $this->user_model->_get_spo() ?: [];
    $hss = $this->user_model->_get_hss() ?: [];
    $hpo = $this->user_model->_get_hpo() ?: [];
    $items = $this->user_model->_get_items() ?: [];
    if ($tmp == '') $this->load->view('default', ['page' => 'users', 'data' => $data, 'items' => $items, 'spo' => $spo, 'hss' => $hss, 'hpo' => $hpo, 'states' => $states, 'outlets' => $outlets, 'tmp' => $tmp]);
    else return $this->load->view('admin/users', ['data' => $data, 'items' => $items, 'spo' => $spo, 'hss' => $hss, 'hpo' => $hpo, 'states' => $states, 'outlets' => $outlets, 'tmp' => $tmp], true);
  }

  function navigate($dir)
  {
    if (($dir != 'next' && $dir != 'prev')) return false;

    $chip = $dir == 'prev' ? '-1 days' : '+1 day';
    $dated = $this->session->userdata('prosc_users_date') ?? date('Y-m-d');
    $dated = date('Y-m-d', strtotime($chip, strtotime($dated)));
    $this->session->set_userdata('prosc_users_date', $dated);
    echo json_encode(['status' => 'success', 'message' => '']);
  }

  function check()
  {
    $name   = trim($this->input->post('name'));
    $type   = trim($this->input->post('type'));
    $phone  = trim($this->input->post('phone'));
    $email  = trim($this->input->post('email'));
    $outlet = trim($this->input->post('outlet'));

    if ($type != 3 && $outlet == '') return false;
    if ($name == '' or $type == '' or $phone == '') return false;


    if (!is_numeric($phone) or strlen($phone) < 11) exit(json_encode(['status' => 'error', 'message' => 'Phone number is invalid']));

    if ($type == 3) {
      return [
        'name'      => $name,
        'type'      => $type,
        'phone'     => $phone,
        'email'     => $email,
        'location'     => 'a577f519b58b533e400cf28a7464576babf92121',
        'warehouse' => 'online_warehouse',
      ];
    } else {
      return [
        'name'      => $name,
        'type'      => $type,
        'phone'     => $phone,
        'email'     => $email,
        'warehouse' => $outlet,
      ];
    }
  }

  function create()
  {
    $data = $this->check();
    if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
    if (!$this->user_model->_post($data))
      exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the insertion operation failed']));

    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
  }

  function update()
  {
    $target = trim($this->input->get('target'));
    if (!$this->user_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));
    $data = $this->check();
    if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
    if (!$this->user_model->_put($data, $target))
      exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the update failed']));

    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
  }

  function delete()
  {
    $target = trim($this->input->get('token'));
    if (!$this->user_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));

    $this->user_model->_drop($target);
    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
  }

  function popup()
  {
    if (!$this->input->is_ajax_request()) {
      $pagedata['heading'] = 'Hold on!';
      $pagedata['message'] = 'The page you tried to reach, restricts direct access.';
      $this->load->view('errors/html/error_404', $pagedata);
    }
    $target = $this->input->get('token');
    $last = $this->user_model->_count() + 1;
    $data = ['data' => '', 'last' => $last];
    $file = $this->user_model->_get(['token' => $target]);
    $states = $this->user_model->_get_states();
    $outlets = $this->user_model->_get_outlets();
    if ($file) $data['data'] = $file;
    $data['states'] = $states;
    $data['outlets'] = $outlets;
    $this->load->view('popups/admin/user', $data);
  }
}
