<?php
defined('BASEPATH') or exit('No direct script access allowed');

class Waybill_supply_control extends CI_Controller
{

  public function __construct()
  {
    parent::__construct();

    if ($this->session->userdata('prosc_user') == "")
      redirect(base_url(), 'refresh');

    $this->load->model('waybill_supply_model');
    $this->load->model('shipping_settings_model');
  }

  public function index()
  {
    $this->pager();
  }

  function pager($tmp = '')
  {
    $data =  [];
    $checkedVoucher =  $this->input->get('voucher');
    $name = $this->input->get('driver');
    $phone = $this->input->get('number');
    $state =   $this->input->get('state');

    if (!$this->input->is_ajax_request() && strstr(current_url(), '.aspx') == '') redirect(base_url('not_found.aspx'), 'refresh');
    $verifySalesItems = $this->waybill_supply_model->_get_verifyItem(['voucher' => $checkedVoucher, 'waybill' => ''], 'er_sales');
    if ($verifySalesItems) {
      $data = $verifySalesItems;
    } else {
      $verifySupplyItems = $this->waybill_supply_model->_get_verifyItem(['voucher' => $checkedVoucher, 'waybill' => ''], 'er_supply');
      $data = $verifySupplyItems;
    }

    $items = $this->waybill_supply_model->_get_items() ?: [];
    $country = $this->shipping_settings_model->_get_country();

    if ($country->value === 'Nigeria') {
      $states = $this->shipping_settings_model->_get_nigeria() ?: [];
    } else {
      $states = $this->shipping_settings_model->_get_uk() ?: [];
    }
    if ($tmp == '') $this->load->view('default', ['page' => 'waybill_supply', 'data' => $data, 'checkedVoucher' =>  $checkedVoucher, 'states' => $states, 'items' => $items, 'name' => $name, 'phone' => $phone, 'state' => $state, 'tmp' => $tmp]);
    else return $this->load->view("admin/waybill_supply", ['data' => $data, 'checkedVoucher' =>  $checkedVoucher, 'states' => $states, 'name' => $name, 'phone' => $phone, 'state' => $state, 'items' => $items, 'tmp' => $tmp], true);
  }

  function check()
  {
    $items = $this->input->post('items');
    $name = trim($this->input->post('driverName'));
    $phone = trim($this->input->post('driverPhone'));
    $state = trim($this->input->post('state'));
    $voucher = trim($this->input->post('voucher'));
    $shippingTokens = array();
    $shippingAddress = '';

    if ($name == '' || $phone == '' || $state == '') {
      return 'Operation failed! Please fill in all fields';
    }

    if (!ctype_alpha(str_replace(' ', '', $name))) {
      return 'Driver name is invalid';
    }

    if (!is_numeric($phone) || strlen($phone) != 11) {
      return 'Phone number must be 11 digits';
    }

    // Check if there are any selected items
    if (empty($items)) {
      return 'Operation failed! No valid selections were made';
    }

    foreach ($items as $item) {
      $order = $this->waybill_supply_model->_get_supply(['voucher' => $voucher, 'item' => $item, 'waybill' => '']);

      $itemDetails = [
        'sales_id' => $order->token,
        'order_id' => $order->voucher,
        'customer' => 'Xcel Supply',
        'delivery_address' => $order->outlet,
        'item' => $order->item,
        'quantity' => $order->quantity,
        'shipment_status' => 'Shipment Created',
        'status' => 0,
      ];

      $shippingAddress = 'Xcel Supply';

      if (!$itemDetails) exit(json_encode(['status' => 'error', 'message' => 'Data not found']));
      $result = $this->waybill_supply_model->_post_shipping($itemDetails, 'er_supply');
      if (!$result) exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the insertion operation failed']));
      array_push($shippingTokens, $result);
    }


    $data = [
      'items'    => implode(' ', $items),
      'state'     => $state,
      'voucher' => $voucher,
      'phone'    => $phone,
      'driver'   => $name,
      'delivery_address' => $shippingAddress,
      'shipping_token'   => implode(' ', $shippingTokens),
      'delivery' => 0,
    ];

    return $data;
  }

  function deliver($items, $waybillToken, $orderVoucher)
  {

    // Ensure $items is not empty
    if (empty($items)) {
      return 'Operation failed! item empty'; // or throw an exception, or handle error
    }

    // Explode $items into an array
    $itemsArray = explode(' ', $items);

    // Iterate over items and apply modifications
    foreach ($itemsArray as $item) {
      if (!empty($item)) {  // Ensure the item is not empty
        // Update the waybill in sales table
        if (!$this->waybill_supply_model->_mod_supply(['voucher' => $orderVoucher, 'item' => $item, 'waybill' => ''], ['waybill' => $waybillToken])) return 'Operation failed! Error sales';

        // Update the waybill in shipping table
        if (!$this->waybill_supply_model->_mod_shipping(['order_id' => $orderVoucher, 'item' => $item, 'waybill' => ''], ['waybill' => $waybillToken])) return 'Operation failed! Error Shipping';
      }
    }

    return true;
  }

  function create()
  {
    $data = $this->check();
    if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in data']));
    if (!is_array($data)) exit(json_encode(['status' => 'error', 'message' => $data]));
    $token = $this->waybill_supply_model->_post($data);
    if (!$token) exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the operation failed']));
    $update = $this->deliver($data['items'], $token,  $data['voucher']);
    if (!$update) exit(json_encode(['status' => 'error', 'message' => $update]));;
    echo json_encode(['status' => 'success', 'message' => base_url('ipanel/waybill.aspx')]);
  }




  function supply()
  {
    $target = trim($this->input->_get('token'));
    if (!$this->waybill_supply_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));

    // $this->waybill_supply_model->_update($target); 
    $this->session->set_flashdata('prosc_message', 'Approved');
    echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
  }



  function update()
  {
    $items = '';
    $data = [];
    $token = $this->input->get('token');
    $target = trim($this->input->get('target'));
    if ($target != 'generate') {
      if (!$this->waybill_supply_model->_get(['token' => $target])) exit(json_encode(['status' => 'error', 'message' => 'A fatal error has occured. <br />Please refresh and try again']));
      $data = $this->check('none');
      if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Fill in all fields']));
      if (!is_array($data)) exit(json_encode(['status' => 'error', 'message' => $data]));
    } else {
      $data = $this->check();
      if (!$data) exit(json_encode(['status' => 'error', 'message' => 'Operation failed! No valid selections were made']));
    }

    $k = ($target == 'generate') ? $token : $target;
    if (!$this->waybill_supply_model->_put($data, $k))
      exit(json_encode(['status' => 'error', 'message' => 'An unknown error occured and the update failed']));

    if ($target == 'generate') {
      $this->deliver($data['items'], $token);
      $this->unsess('none');
      echo (json_encode(['status' => 'success', 'message' => '', 'extra' => '']));
    } else {
      echo (json_encode(['status' => 'success', 'message' => $this->pager('dump')]));
    }
  }




  function unsess($trx = '')
  {
    $target = $this->input->get('token');
    if ($target == '' or $trx == 'none') {
      unset($_SESSION['prosc_way_token']);
      unset($_SESSION['prosc_way_driver']);
      unset($_SESSION['prosc_way_date']);
      unset($_SESSION['prosc_way_phone']);
      unset($_SESSION['prosc_way_update']);
    } else {
      $data = $this->waybill_supply_model->_get(['token' => $target]);
      if (!$data) exit(json_encode(['status' => 'success', 'message' => '']));
      $_SESSION['prosc_way_token']  = $data->token;
      $_SESSION['prosc_way_driver'] = $data->driver;
      $_SESSION['prosc_way_date']   = $data->date;
      $_SESSION['prosc_way_phone']  = $data->phone;
      $_SESSION['prosc_way_update'] = true;
    }
    if ($trx == '')
      echo (json_encode(['status' => 'success', 'message' => '']));
  }
}
