<?php
if (!defined('BASEPATH'))
  exit('No direct script access allowed');

class Customer_model extends CI_Model {

  function __construct() {
    parent::__construct();
  }

  function _sum_payment($client, $token='')
  {
    $this->db->select("SUM(amount) as total");
    $sum = $this->db->get_where('er_lodgement', ['customer'=>$client, 'token !='=>$token, 'status !='=>1]);
    if ( ! $sum->num_rows() > 0) return 0;
    return $sum->row('total');
  }

  function _sum_supply($client, $token='')
  {
    $this->db->select("SUM(total) as total");
    $sum = $this->db->get_where('er_sales', ['customer'=>$client, 'token !='=>$token, 'status !='=>1]);
    if ( ! $sum->num_rows() > 0) return 0;
    return $sum->row('total');
  }

  function _get($params) 
  {
    $this->db->where('status', 0);
    $user = $this->db->get_where('er_customers', $params);
    if ( ! ($user->num_rows() > 0)) return false;
    return $user->row();
  }

  function _get_all($params = '') 
  {
    if (!isset($_SESSION['prosc_admin'])) $this->db->where('warehouse', $_SESSION['prosc_warehouse']);
    if ($params != '') $this->db->where($params);
    $debtors = $this->db->get_where('er_customers', ['status'=>0]);
    if ( ! ($debtors->num_rows() > 0)) return false;
    return $debtors->result_array();
  }

  function _get_users() 
  {
    $users = $this->db->get('er_admin');
    if ( ! ($users->num_rows() > 0)) return false;
    return $users->result_array();
  }

  function _get_outlets() 
  {
    $this->db->order_by('type ASC, name ASC');
    $outlets = $this->db->get_where('er_warehouse', ['status'=>0]);
    if ( ! ($outlets->num_rows() > 0)) return false;
    return $outlets->result_array();
  }

  function _get_sum($table, $col, $filter='')
  {
    $table = 'er_'.$table;
    $this->db->select('SUM('.$col.') as total');
    return $this->db->get_where($table, $filter)->row('total') ?? 0;
  }

  // Supply History Modelling

  function _get_history($target, $type='debtors')
  {
    $this->db->select('*, SUM(total) as total');
    $this->db->group_by('voucher')->order_by('voucher')->limit(10);
    $supplies = $this->db->get_where('er_sales', ['type'=>1, 'customer'=>$target, 'status'=>0]);
    if ( ! $supplies->num_rows() > 0) return false;
    
    return $supplies->result_array();
  }

  function _get_payments($target)
  {
    $this->db->select('*, SUM(amount) as total');
    $this->db->group_by('supply_id');
    $payments = $this->db->get_where('er_payments', ['payer_id'=>$target, 'status'=>0]);
    if ( ! $payments->num_rows() > 0) return false;

    $data = [];
    foreach ($payments->result_array() as $row)
      $data[$row['supply_id']] = $row['total'];

    return $data;
  }

  function _get_client($token)
  {
    $client = $this->db->get_where('er_customers', ['token'=>$token]);
    if ( ! $client->num_rows() > 0) return ['name'=>'', 'phone'=>'', 'days'=>0];

    return ['name'=>$client->row('name'), 'phone'=>$client->row('phone'), 'days'=>$client->row('days')];
  }

  function _get_balances($target)
  {
    $supply = $this->_get_sum('sales', 'total', ['customer'=>$target, 'status'=>0, 'type'=>1]);
    $payment = $this->_get_sum('payments', 'amount', ['payer_id'=>$target, 'status'=>0]);

    return ['supply'=>$supply, 'payment'=>$payment];
  }

  // End Supply History Modelling

  function _count()
  {
    return $this->db->count_all_results('er_customers');
  }

  function _put($params, $target) 
  {
    $this->db->where('token', $target);
    $user = $this->db->update('er_customers', $params);
    if ( ! $user) return false;
    return true;
  }

  function _post($data)
  {
    $hash = base64_encode(random_bytes(32).date('Hisa'));
    $hash = strtr($hash, '+/', '-_');
    $hash = rtrim($hash, '=');
    $last = $this->_count() + 1;
    $uuid = str_repeat('0', 3 - strlen($last)) . $last;
    $data['token'] = $hash;
    $data['serial'] = 'SCC '.$uuid;
    $data['done_by'] = $this->session->userdata('prosc_user');
    if ( ! $this->db->insert('er_customers', $data)) return false;
    return $data['token'];
  }

  function _drop($target)
  {
    $this->db->where('token', $target);
    $this->db->update('er_customers', ['status'=>'1']);
  }
}
